<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LayerList</name>
    <message>
        <location filename="../LayerList.js" line="+197"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>&amp;Layer List</source>
        <translation>&amp;L 画層リスト</translation>
    </message>
    <message>
        <location line="-54"/>
        <location line="+109"/>
        <source>Layer List</source>
        <translation>画層リスト</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Enable alternating row colors</source>
        <translation>行の交互色を使用する</translation>
    </message>
</context>
</TS>
